# :octicons-code-24: - Development

This section is intended to all the developers who want to contribute to the project by:

- fixing one or more bugs
- improving the library
- creating a new `Interaction`

Depending on the scope, different actions should be taken into consideration.

## Bug & Improvements

!!! warning
    :material-hammer-wrench: - Section under construction.

## New Interactions

!!! warning
    :material-hammer-wrench: - Section under construction.

## Pull Requests

!!! warning
    :material-hammer-wrench: - Section under construction.

## Testing

!!! warning
    :material-hammer-wrench: - Section under construction.